@@ -1,8 +1,8 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
 
-import urllib2 as urllib
-from urllib import urlretrieve
+import urllib.error
+import urllib.request
 from os import path
 from re import compile
 from spyprot import Command
@@ -43,15 +43,15 @@ def getCath(pdbcode, chain):
     if not path.isfile(hcath):
         if not path.exists(DEFAULT_DATA_FILE_PATH):
             os.makedirs(DEFAULT_DATA_FILE_PATH)
-        urlretrieve(cath_uri, hcath_tmp)
+        urllib.request.urlretrieve(cath_uri, hcath_tmp)
         cmd = Command('egrep -v "^NAME|^DLEN|^S|^VER|^NSE|^FOR|^DSEQ" ' + hcath_tmp + '>' + hcath)
-        cmd.run(5000)
+        cmd.run(1000)
         os.remove(hcath_tmp)
     pdbcode = pdbcode.lower()
     chain = chain
     record = compile(r'^DOMAIN    ' + pdbcode + chain)
     results = []
-    with open(hcath, 'r') as cddf:
+    with open(hcath, 'r', encoding='utf-8') as cddf:
         found = False
         for line in cddf:
             if record.match(line):
