@@ -1,5 +1,7 @@
 #!/usr/bin/env python
-import urllib2 as urllib
+import urllib.error
+import urllib.parse
+import urllib.request
 from itertools import count, groupby
 from os import path
 import tempfile
@@ -25,8 +27,8 @@ class XmlPdbParser:
 
     def download_if_not_exist(self):
         pdb_xml_file = path.join(self.work_dir, self.pdb + '.xml.gz')
-        if not path.isfile(pdb_xml_file):
-            f = urllib.urlopen('http://www.rcsb.org/pdb/files/' + self.pdb + '.xml.gz')
+        if not path.isfile(pdb_xml_file) or path.getsize(pdb_xml_file) == 0:
+            f = urllib.request.urlopen('https://www.rcsb.org/pdb/files/' + self.pdb + '.xml.gz')
             fw = open(pdb_xml_file, "wb")
             fw.write(f.read())
             fw.close()
@@ -36,7 +38,7 @@ class XmlPdbParser:
 
 class getCoordinates(XmlPdbParser):
     def __init__(self, pdbcode, work_dir=tempfile.gettempdir(), localfile=False, atom="CA"):
-        XmlPdbParser.__init__(self, pdbcode, None, work_dir, localfile, atom=atom)
+        super().__init__(pdbcode, None, work_dir, localfile, atom=atom)
         l = self.root.xpath(
             "//PDBx:atom_siteCategory/PDBx:atom_site[PDBx:auth_atom_id=\"" + atom + "\"][PDBx:pdbx_PDB_model_num='1'][PDBx:group_PDB='ATOM']/PDBx:auth_asym_id",
             namespaces=self.NS)
@@ -140,7 +142,7 @@ class getCoordinates(XmlPdbParser):
 
 class fetchPDBinfo(XmlPdbParser):
     def __init__(self, pdbcode, chain='A', work_dir=tempfile.gettempdir(), localfile=False, atom="CA"):
-        XmlPdbParser.__init__(self, pdbcode, chain, work_dir, localfile, atom=atom)
+        super().__init__(pdbcode, chain, work_dir, localfile, atom=atom)
         l = self.root.xpath(
             "//PDBx:atom_siteCategory/PDBx:atom_site[PDBx:auth_atom_id=\"" + atom + "\"][PDBx:pdbx_PDB_model_num='1'][PDBx:group_PDB='ATOM']/PDBx:auth_asym_id",
             namespaces=self.NS)
@@ -150,7 +152,6 @@ class fetchPDBinfo(XmlPdbParser):
             if e is not None and e.text not in self.ordered_chains:
                 self.chains.update(e.text)
                 self.ordered_chains.append(e.text)
-
         self.codification = {"ALA": 'A',
                              "CYS": 'C',
                              "ASP": 'D',
@@ -226,7 +227,6 @@ class fetchPDBinfo(XmlPdbParser):
                              "TYR": 'Y'}
         self._getCAmissing()
 
-
     def getCalfaBreaks(self, preserve_seqid=False):
         l = self.root.xpath(
             "//PDBx:atom_siteCategory/PDBx:atom_site[not(PDBx:label_alt_id/text()) or PDBx:label_alt_id='A'][PDBx:auth_atom_id=\"" + self.atom + "\"][PDBx:pdbx_PDB_model_num='1'][PDBx:group_PDB='ATOM' or (PDBx:group_PDB='HETATM' and PDBx:label_comp_id='MSE') or (PDBx:group_PDB='HETATM' and PDBx:label_comp_id='ORN') or (PDBx:group_PDB='HETATM' and PDBx:label_comp_id='PCA') or (PDBx:group_PDB='HETATM' and PDBx:label_comp_id='DGL')][PDBx:auth_asym_id='" + self.chain + "']",
@@ -396,13 +396,6 @@ if __name__ == "__main__":
     # r = fetchPDBinfo('/tmp','1j85', 'A', localfile=False, atom="CA")
     print(r.getSeqLength())
     print(r.getCAlen())
-
-    #p = fetchPDBinfo('7KPM','tt','/tmp')
-    p = fetchPDBinfo('1J85', 'A', '/tmp', localfile=False, atom="CA")
-    r = p.getPdbCreationDate()
-    #print(p.getChains())
-    #print(p.getOrderedChains())
-    #print(r)
     # b = getCoordinates("/tmp", "1uak")
     # b.getCalfaPdbFormat("A", output=path.join("/tmp", "t.pdb"))
     # a = fetchPDBinfo("/tmp", "1uak","A")
